@@ -86,45 +86,14 @@ char *tgetstr(char *NAME, char **AREA);
 static char term_buffer[2048];
 #endif
 
-#ifdef AMIGA
-#  define __USE_SYSBASE
-#  include <dos.h>
-#  include <dos/dos.h>
-#  include <dos/dosasl.h>
-#  include <proto/dos.h>
-#  include <proto/exec.h>
-#  include <signal.h>
-#endif
-
 /*  -=><=- -=><=- -=><=- -=><=- -=><=- -=><=- -=><=- -=><=- -=><=-  */
 
-
-#ifdef AMIGA
-const char
-    VersString[] = "$VER: ChkTeX v" PACKAGE_VERSION " " __AMIGADATE__
-    " Copyright (c) 1995-96 Jens T. Berger Thielemann "
-    "<jensthi@ifi.uio.no>",
-    __stdiowin[] = "CON:0/10/640/180/ChkTeX", __stdiov37[] =
-    "/AUTO/CLOSE/WAIT";
-
-const unsigned long __MemPoolPuddleSize = 16384, __MemPoolThreshSize = 8192;
-
-static struct AnchorPath *AnchorPath = NULL;
-
-static void KillAnchorPath(void);
-static char *InitAnchorPath(char *String);
-#  define V37 (DOSBase->dl_lib.lib_Version > 36)
-#endif
-
-
 /*
  * This is the name of the global resource file.
  */
 
 #ifndef SYSCONFDIR
-#  ifdef AMIGA
-#    define SYSCONFDIR  "S:"
-#  elif defined(__unix__)
+#  if defined(__unix__)
 #    define SYSCONFDIR "/usr/local/lib/"
 #  elif defined(__MSDOS__)
 #    define SYSCONFDIR "\\emtex\\data\\"
@@ -227,15 +196,7 @@ int SetupVars(void)
                 *ConfigFile = 0;
             break;
         case liUsrDir:         /* User dir for resource files */
-#ifdef AMIGA
-
-            if (V37)
-                strcpy(ConfigFile, "ENV:");
-            else
-                strcpy(ConfigFile, "S:");
-
-            tackon(ConfigFile, LOCALRCFILE);
-#elif defined(__unix__)
+#if defined(__unix__)
 
             if ((Env = getenv("HOME")) || (Env = getenv("LOGDIR")))
             {
@@ -501,97 +462,3 @@ static int SearchFile(char *Dir, const char *Filename, const char *App)
     return (Found);
 }
 #endif /* USE_RECURSE */
-
-
-
-/*  -=><=- -=><=- -=><=- -=><=- -=><=- -=><=- -=><=- -=><=- -=><=-  */
-
-/*
- * This function should be called first with String being a file pattern.
- * It should then return the first filename matching that pattern.
- * Subsequent calls will be made with String = NULL; it should then return
- * any other filenames that matches the same pattern.
- * If the first call is made with NULL, you should return NULL.
- * It may be called more than once with String != NULL, however, you need
- * only to keep track of the last invocation.
- *
- * If a string doesn't match any pattern at all, return the string itself.
- *
- * Don't assume that the String passed will live on until the next
- * invocation, though. strdup() it if you need it after the first time.
- */
-
-#ifdef AMIGA
-
-char *MatchFileName(char *String)
-{
-    char *Retval = NULL;
-
-    if (AnchorPath || String)   /* Is this the first invocation? */
-    {
-        if (V37)
-        {
-            if (!(AnchorPath))
-            {
-                if (AnchorPath = malloc(sizeof(struct AnchorPath) + FMSIZE))
-                {
-                    Retval = InitAnchorPath(String);
-                    atexit(&KillAnchorPath);
-                }
-            }
-            else
-            {
-                if (String)
-                {
-                    MatchEnd(AnchorPath);
-                    Retval = InitAnchorPath(String);
-                }
-                else
-                {
-                    if (!(MatchNext(AnchorPath)))
-                        Retval = AnchorPath->ap_Buf;
-                }
-            }
-        }
-        else                    /* ARP support may be added in the future */
-            Retval = String;
-
-        if (AnchorPath && AnchorPath->ap_FoundBreak)
-            raise(SIGINT);
-    }
-
-    if (!Retval && String)
-        Retval = String;
-
-    return (Retval);
-}
-
-static void KillAnchorPath(void)
-{
-    MatchEnd(AnchorPath);
-}
-
-static char *InitAnchorPath(char *String)
-{
-    char *Retval = NULL;
-
-    AnchorPath->ap_BreakBits = SIGBREAKF_CTRL_C;
-    AnchorPath->ap_Strlen = FMSIZE;
-    AnchorPath->ap_FoundBreak = FALSE;
-    AnchorPath->ap_Flags = 0L;
-
-    if (!(MatchFirst(String, AnchorPath)))
-        Retval = AnchorPath->ap_Buf;
-    else
-        PrintPrgErr(pmNoFileMatch, String);
-
-    AnchorPath->ap_Flags &= ~(APF_DODIR);
-    return (Retval);
-}
-
-#else
-char *MatchFileName(char *String)
-{
-    return (String);
-}
-#endif
